@@ -1,33 +1,37 @@
-const TARGET_EXE_PATH: &'static str = env!("CARGO_BIN_EXE_aki-mcycle");
+const TARGET_EXE_PATH: &'static str = env!(concat!("CARGO_BIN_EXE_", env!("CARGO_PKG_NAME")));
 
 macro_rules! help_msg {
     () => {
         concat!(
             version_msg!(),
             "\n",
-            "Usage:\n",
-            "  aki-mcycle [options]\n",
-            "\n",
-            "mark up text with the cyclic color.\n",
-            "\n",
-            "Options:\n",
-            "  -e, --exp <exp>   write it in the cyclic color (default: ' ([0-9A-Z]{3,}):')\n",
-            "\n",
-            "  -H, --help        display this help and exit\n",
-            "  -V, --version     display version information and exit\n",
-            "  -X <x-options>    x options. try -X help\n",
-            "\n",
-            "Option Parameters:\n",
-            "  <exp>     regular expression, color the entire match with the cyclic color.\n",
-            "\n",
-            "Environments:\n",
-            "  AKI_MCYCLE_COLOR_SEQ_RED_ST       red start sequence specified by ansi\n",
-            "  AKI_MCYCLE_COLOR_SEQ_GREEN_ST     green start sequence specified by ansi\n",
-            "  AKI_MCYCLE_COLOR_SEQ_BLUE_ST      blue start sequence specified by ansi\n",
-            "  AKI_MCYCLE_COLOR_SEQ_CYAN_ST      cyan start sequence specified by ansi\n",
-            "  AKI_MCYCLE_COLOR_SEQ_MAGENDA_ST   magenda start sequence specified by ansi\n",
-            "  AKI_MCYCLE_COLOR_SEQ_YELLOW_ST    yellow start sequence specified by ansi\n",
-            "  AKI_MCYCLE_COLOR_SEQ_ED           color end sequence specified by ansi\n",
+            indoc::indoc!(
+                r#"
+            Usage:
+              aki-mcycle [options]
+
+            mark up text with the cyclic color.
+
+            Options:
+              -e, --exp <exp>   write it in the cyclic color (default: ' ([0-9A-Z]{3,}):')
+
+              -H, --help        display this help and exit
+              -V, --version     display version information and exit
+              -X <x-options>    x options. try -X help
+
+            Option Parameters:
+              <exp>     regular expression, color the entire match with the cyclic color.
+
+            Environments:
+              AKI_MCYCLE_COLOR_SEQ_RED_ST       red start sequence specified by ansi
+              AKI_MCYCLE_COLOR_SEQ_GREEN_ST     green start sequence specified by ansi
+              AKI_MCYCLE_COLOR_SEQ_BLUE_ST      blue start sequence specified by ansi
+              AKI_MCYCLE_COLOR_SEQ_CYAN_ST      cyan start sequence specified by ansi
+              AKI_MCYCLE_COLOR_SEQ_MAGENDA_ST   magenda start sequence specified by ansi
+              AKI_MCYCLE_COLOR_SEQ_YELLOW_ST    yellow start sequence specified by ansi
+              AKI_MCYCLE_COLOR_SEQ_ED           color end sequence specified by ansi
+            "#
+            ),
             "\n"
         )
     };
@@ -57,10 +61,10 @@ macro_rules! fixture_text10k {
     };
 }
 
-mod helper;
+//mod helper;
 
 mod test_0 {
-    use crate::helper::exec_target;
+    use exec_target::exec_target;
     //use exec_target::args_from;
     const TARGET_EXE_PATH: &'static str = super::TARGET_EXE_PATH;
     //
@@ -122,7 +126,7 @@ mod test_0 {
 }
 
 mod test_1 {
-    use crate::helper::exec_target_with_env_in;
+    use exec_target::exec_target_with_env_in;
     //use exec_target::args_from;
     const TARGET_EXE_PATH: &'static str = super::TARGET_EXE_PATH;
     //
@@ -204,7 +208,7 @@ mod test_1 {
 }
 
 mod test_3 {
-    use crate::helper::exec_target;
+    use exec_target::exec_target;
     const TARGET_EXE_PATH: &'static str = super::TARGET_EXE_PATH;
     //
     #[test]
